/**
 * DevExtreme (cjs/exporter/jspdf/v3/rows_splitting.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.splitRectsByPages = splitRectsByPages;
var _type = require("../../../core/utils/type");
var _draw_utils = require("./draw_utils");

function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread()
}

function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")
}

function _unsupportedIterableToArray(o, minLen) {
    if (!o) {
        return
    }
    if ("string" === typeof o) {
        return _arrayLikeToArray(o, minLen)
    }
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if ("Object" === n && o.constructor) {
        n = o.constructor.name
    }
    if ("Map" === n || "Set" === n) {
        return Array.from(o)
    }
    if ("Arguments" === n || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) {
        return _arrayLikeToArray(o, minLen)
    }
}

function _iterableToArray(iter) {
    if ("undefined" !== typeof Symbol && null != iter[Symbol.iterator] || null != iter["@@iterator"]) {
        return Array.from(iter)
    }
}

function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        return _arrayLikeToArray(arr)
    }
}

function _arrayLikeToArray(arr, len) {
    if (null == len || len > arr.length) {
        len = arr.length
    }
    for (var i = 0, arr2 = new Array(len); i < len; i++) {
        arr2[i] = arr[i]
    }
    return arr2
}

function splitRectsByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally) {
    if (!(0, _type.isDefined)(rects) || 0 === rects.length) {
        return [
            []
        ]
    }
    var rectsByPage = splitRectsHorizontalByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally);
    return rectsByPage
}

function splitRectsHorizontalByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally) {
    var pages = [];
    var rectsToSplit = _toConsumableArray(rects);
    var _loop = function() {
        var currentPageMaxRectRight = 0;
        var currentPageRects = rectsToSplit.filter((function(rect) {
            var currentRectRight = (0, _draw_utils.roundToThreeDecimals)(rect.x + rect.w);
            if (currentRectRight <= maxBottomRight.x) {
                if (currentPageMaxRectRight <= currentRectRight) {
                    currentPageMaxRectRight = currentRectRight
                }
                return true
            } else {
                return false
            }
        }));
        var rectsToSeparate = rectsToSplit.filter((function(rect) {
            var currentRectLeft = (0, _draw_utils.roundToThreeDecimals)(rect.x);
            var currentRectRight = (0, _draw_utils.roundToThreeDecimals)(rect.x + rect.w);
            if (currentRectLeft < currentPageMaxRectRight && currentPageMaxRectRight < currentRectRight) {
                return true
            }
        }));
        rectsToSeparate.forEach((function(rect) {
            var args = {
                sourceRect: rect,
                leftRect: {
                    x: rect.x,
                    y: rect.y,
                    w: currentPageMaxRectRight - rect.x,
                    h: rect.h
                },
                rightRect: {
                    x: currentPageMaxRectRight,
                    y: rect.y,
                    w: rect.w - (currentPageMaxRectRight - rect.x),
                    h: rect.h
                }
            };
            onSeparateRectHorizontally(args);
            currentPageRects.push(args.leftRect);
            rectsToSplit.push(args.rightRect);
            var index = rectsToSplit.indexOf(rect);
            if (-1 !== index) {
                rectsToSplit.splice(index, 1)
            }
        }));
        currentPageRects.forEach((function(rect) {
            var index = rectsToSplit.indexOf(rect);
            if (-1 !== index) {
                rectsToSplit.splice(index, 1)
            }
        }));
        rectsToSplit.forEach((function(rect) {
            rect.x = void 0 !== currentPageMaxRectRight ? rect.x - currentPageMaxRectRight + margin.left + topLeft.x : rect.x
        }));
        if (currentPageRects.length > 0) {
            pages.push(currentPageRects)
        } else {
            pages.push(rectsToSplit);
            return "break"
        }
    };
    while (rectsToSplit.length > 0) {
        var _ret = _loop();
        if ("break" === _ret) {
            break
        }
    }
    return pages
}
