/**
 * DevExtreme (esm/exporter/jspdf/v3/rows_splitting.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import {
    isDefined
} from "../../../core/utils/type";
import {
    roundToThreeDecimals
} from "./draw_utils";

function splitRectsByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally) {
    if (!isDefined(rects) || 0 === rects.length) {
        return [
            []
        ]
    }
    var rectsByPage = splitRectsHorizontalByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally);
    return rectsByPage
}

function splitRectsHorizontalByPages(rects, margin, topLeft, maxBottomRight, onSeparateRectHorizontally) {
    var pages = [];
    var rectsToSplit = [...rects];
    var _loop = function() {
        var currentPageMaxRectRight = 0;
        var currentPageRects = rectsToSplit.filter(rect => {
            var currentRectRight = roundToThreeDecimals(rect.x + rect.w);
            if (currentRectRight <= maxBottomRight.x) {
                if (currentPageMaxRectRight <= currentRectRight) {
                    currentPageMaxRectRight = currentRectRight
                }
                return true
            } else {
                return false
            }
        });
        var rectsToSeparate = rectsToSplit.filter(rect => {
            var currentRectLeft = roundToThreeDecimals(rect.x);
            var currentRectRight = roundToThreeDecimals(rect.x + rect.w);
            if (currentRectLeft < currentPageMaxRectRight && currentPageMaxRectRight < currentRectRight) {
                return true
            }
        });
        rectsToSeparate.forEach(rect => {
            var args = {
                sourceRect: rect,
                leftRect: {
                    x: rect.x,
                    y: rect.y,
                    w: currentPageMaxRectRight - rect.x,
                    h: rect.h
                },
                rightRect: {
                    x: currentPageMaxRectRight,
                    y: rect.y,
                    w: rect.w - (currentPageMaxRectRight - rect.x),
                    h: rect.h
                }
            };
            onSeparateRectHorizontally(args);
            currentPageRects.push(args.leftRect);
            rectsToSplit.push(args.rightRect);
            var index = rectsToSplit.indexOf(rect);
            if (-1 !== index) {
                rectsToSplit.splice(index, 1)
            }
        });
        currentPageRects.forEach(rect => {
            var index = rectsToSplit.indexOf(rect);
            if (-1 !== index) {
                rectsToSplit.splice(index, 1)
            }
        });
        rectsToSplit.forEach(rect => {
            rect.x = void 0 !== currentPageMaxRectRight ? rect.x - currentPageMaxRectRight + margin.left + topLeft.x : rect.x
        });
        if (currentPageRects.length > 0) {
            pages.push(currentPageRects)
        } else {
            pages.push(rectsToSplit);
            return "break"
        }
    };
    while (rectsToSplit.length > 0) {
        var _ret = _loop();
        if ("break" === _ret) {
            break
        }
    }
    return pages
}
export {
    splitRectsByPages
};
