/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/data_grid_light.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["accessKey", "activeStateEnabled", "children", "className", "columns", "dataSource", "disabled", "focusStateEnabled", "height", "hint", "hoverStateEnabled", "keyExpr", "onClick", "onKeyDown", "rtlEnabled", "tabIndex", "visible", "width"];
import {
    createVNode,
    createComponentVNode,
    normalizeProps
} from "inferno";
import {
    InfernoEffect,
    InfernoWrapperComponent
} from "@devextreme/runtime/inferno";
import {
    createValue,
    createGetter,
    Plugins
} from "../../../utils/plugin/context";
import {
    Widget
} from "../../common/widget";
import {
    BaseWidgetProps
} from "../../common/base_props";
import {
    TableContent
} from "./views/table_content";
import {
    TableHeader
} from "./views/table_header";
import {
    Footer
} from "./views/footer";
export var VisibleItems = createGetter([]);
export var VisibleColumns = createGetter([]);
export var DataSource = createValue();
export var KeyExprPlugin = createValue();
export var TotalCount = createValue();
export var viewFunction = viewModel => normalizeProps(createComponentVNode(2, Widget, _extends({
    accessKey: viewModel.props.accessKey,
    activeStateEnabled: viewModel.props.activeStateEnabled,
    aria: viewModel.aria,
    disabled: viewModel.props.disabled,
    focusStateEnabled: viewModel.props.focusStateEnabled,
    height: viewModel.props.height,
    hint: viewModel.props.hint,
    hoverStateEnabled: viewModel.props.hoverStateEnabled,
    rtlEnabled: viewModel.props.rtlEnabled,
    tabIndex: viewModel.props.tabIndex,
    visible: viewModel.props.visible,
    width: viewModel.props.width
}, viewModel.restAttributes, {
    children: createVNode(1, "div", "dx-datagrid dx-gridbase-container", [createComponentVNode(2, TableHeader, {
        columns: viewModel.visibleColumns
    }), createComponentVNode(2, TableContent, {
        columns: viewModel.visibleColumns,
        dataSource: viewModel.visibleItems
    }), createComponentVNode(2, Footer), viewModel.props.children], 0, {
        role: "grid",
        "aria-label": "Data grid"
    })
})));
export var DataGridLightProps = Object.create(Object.prototype, _extends(Object.getOwnPropertyDescriptors(BaseWidgetProps), Object.getOwnPropertyDescriptors({
    dataSource: Object.freeze([]),
    columns: Object.freeze([])
})));
var aria = {
    role: "presentation"
};
import {
    createReRenderEffect
} from "@devextreme/runtime/inferno";
export class DataGridLight extends InfernoWrapperComponent {
    constructor(props) {
        super(props);
        this.plugins = new Plugins;
        this.__getterCache = {};
        this.state = {
            visibleItems: [],
            visibleColumns: []
        };
        this.updateTotalCount = this.updateTotalCount.bind(this);
        this.updateVisibleItems = this.updateVisibleItems.bind(this);
        this.setDataSourceToVisibleItems = this.setDataSourceToVisibleItems.bind(this);
        this.updateVisibleColumns = this.updateVisibleColumns.bind(this);
        this.setInitialColumnsToVisibleColumns = this.setInitialColumnsToVisibleColumns.bind(this);
        this.updateKeyExpr = this.updateKeyExpr.bind(this);
        this.updateDataSource = this.updateDataSource.bind(this)
    }
    createEffects() {
        return [new InfernoEffect(this.updateTotalCount, [this.plugins, this.props.dataSource]), new InfernoEffect(this.updateVisibleItems, [this.plugins]), new InfernoEffect(this.setDataSourceToVisibleItems, [this.plugins, this.props.dataSource]), new InfernoEffect(this.updateVisibleColumns, [this.plugins]), new InfernoEffect(this.setInitialColumnsToVisibleColumns, [this.plugins, this.props.columns]), new InfernoEffect(this.updateKeyExpr, [this.plugins, this.props.keyExpr]), new InfernoEffect(this.updateDataSource, [this.plugins, this.props.dataSource]), createReRenderEffect()]
    }
    updateEffects() {
        var _this$_effects$, _this$_effects$2, _this$_effects$3, _this$_effects$4, _this$_effects$5, _this$_effects$6, _this$_effects$7;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins, this.props.dataSource]);
        null === (_this$_effects$2 = this._effects[1]) || void 0 === _this$_effects$2 ? void 0 : _this$_effects$2.update([this.plugins]);
        null === (_this$_effects$3 = this._effects[2]) || void 0 === _this$_effects$3 ? void 0 : _this$_effects$3.update([this.plugins, this.props.dataSource]);
        null === (_this$_effects$4 = this._effects[3]) || void 0 === _this$_effects$4 ? void 0 : _this$_effects$4.update([this.plugins]);
        null === (_this$_effects$5 = this._effects[4]) || void 0 === _this$_effects$5 ? void 0 : _this$_effects$5.update([this.plugins, this.props.columns]);
        null === (_this$_effects$6 = this._effects[5]) || void 0 === _this$_effects$6 ? void 0 : _this$_effects$6.update([this.plugins, this.props.keyExpr]);
        null === (_this$_effects$7 = this._effects[6]) || void 0 === _this$_effects$7 ? void 0 : _this$_effects$7.update([this.plugins, this.props.dataSource])
    }
    getChildContext() {
        return _extends({}, this.context, {
            PluginsContext: this.plugins
        })
    }
    updateTotalCount() {
        this.plugins.set(TotalCount, this.props.dataSource.length)
    }
    updateVisibleItems() {
        return this.plugins.watch(VisibleItems, items => {
            this.setState(__state_argument => ({
                visibleItems: items
            }))
        })
    }
    setDataSourceToVisibleItems() {
        return this.plugins.extend(VisibleItems, -1, () => this.props.dataSource)
    }
    updateVisibleColumns() {
        return this.plugins.watch(VisibleColumns, columns => {
            this.setState(__state_argument => ({
                visibleColumns: columns
            }))
        })
    }
    setInitialColumnsToVisibleColumns() {
        return this.plugins.extend(VisibleColumns, -1, () => this.columns)
    }
    updateKeyExpr() {
        this.plugins.set(KeyExprPlugin, this.props.keyExpr)
    }
    updateDataSource() {
        this.plugins.set(DataSource, this.props.dataSource)
    }
    get aria() {
        return aria
    }
    get columns() {
        if (void 0 !== this.__getterCache.columns) {
            return this.__getterCache.columns
        }
        return this.__getterCache.columns = (() => {
            var userColumns = this.props.columns;
            return userColumns.map(userColumn => ({
                dataField: userColumn
            }))
        })()
    }
    get restAttributes() {
        var _this$props = this.props,
            restProps = _objectWithoutPropertiesLoose(_this$props, _excluded);
        return restProps
    }
    componentWillUpdate(nextProps, nextState, context) {
        super.componentWillUpdate();
        if (this.props.columns !== nextProps.columns) {
            this.__getterCache.columns = void 0
        }
    }
    render() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            visibleItems: this.state.visibleItems,
            visibleColumns: this.state.visibleColumns,
            plugins: this.plugins,
            aria: this.aria,
            columns: this.columns,
            restAttributes: this.restAttributes
        })
    }
}
DataGridLight.defaultProps = DataGridLightProps;
