/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/pager/pager.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["allowedPageSizes", "displayMode", "infoText", "showInfo", "showNavigationButtons", "showPageSizeSelector", "visible"];
import {
    createComponentVNode
} from "inferno";
import {
    BaseInfernoComponent
} from "@devextreme/runtime/inferno";
import {
    PlaceholderExtender
} from "../../../../utils/plugin/placeholder_extender";
import messageLocalization from "../../../../../localization/message";
import {
    PagerContent
} from "../../../pager/content";
import {
    PageIndex,
    PageSize,
    PageCount,
    SetPageIndex,
    SetPageSize
} from "../paging/plugins";
import {
    TotalCount
} from "../data_grid_light";
import {
    FooterPlaceholder
} from "../views/footer";
import {
    PluginsContext
} from "../../../../utils/plugin/context";
var DATAGRID_PAGER_CLASS = "dx-datagrid-pager";
export var viewFunction = viewModel => createComponentVNode(2, PlaceholderExtender, {
    type: FooterPlaceholder,
    order: 1,
    deps: [PageIndex, PageSize, TotalCount, PageCount],
    template: _ref => {
        var [pageIndex, pageSize, totalCount, pageCount] = _ref;
        return createComponentVNode(2, PagerContent, {
            className: DATAGRID_PAGER_CLASS,
            pageSizes: viewModel.allowedPageSizes,
            displayMode: viewModel.props.displayMode,
            infoText: viewModel.props.infoText,
            showInfo: viewModel.props.showInfo,
            showNavigationButtons: viewModel.props.showNavigationButtons,
            showPageSizes: viewModel.props.showPageSizeSelector,
            pageCount: pageCount,
            visible: viewModel.props.visible,
            totalCount: totalCount,
            pageIndex: pageIndex,
            pageIndexChange: viewModel.onPageIndexChange,
            pageSize: "all" === pageSize ? 0 : pageSize,
            pageSizeChange: viewModel.onPageSizeChange
        })
    }
});
export var PagerProps = {
    allowedPageSizes: "auto",
    displayMode: "adaptive",
    get infoText() {
        return messageLocalization.format("dxPager-infoText")
    },
    showInfo: false,
    showNavigationButtons: false,
    showPageSizeSelector: false,
    visible: true
};
export class Pager extends BaseInfernoComponent {
    constructor(props) {
        super(props);
        this.state = {};
        this.__getterCache = {};
        this.onPageSizeChange = this.onPageSizeChange.bind(this);
        this.onPageIndexChange = this.onPageIndexChange.bind(this)
    }
    get plugins() {
        if ("PluginsContext" in this.context) {
            return this.context.PluginsContext
        }
        return PluginsContext
    }
    onPageSizeChange(pageSize) {
        var setPageSize = this.plugins.getValue(SetPageSize);
        if (!setPageSize) {
            return
        }
        if (0 === pageSize) {
            setPageSize("all")
        } else {
            setPageSize(pageSize)
        }
    }
    onPageIndexChange(pageIndex) {
        var _this$plugins$getValu;
        null === (_this$plugins$getValu = this.plugins.getValue(SetPageIndex)) || void 0 === _this$plugins$getValu ? void 0 : _this$plugins$getValu(pageIndex)
    }
    get allowedPageSizes() {
        if (void 0 !== this.__getterCache.allowedPageSizes) {
            return this.__getterCache.allowedPageSizes
        }
        return this.__getterCache.allowedPageSizes = (() => {
            var _this$plugins$getValu2;
            var pageSize = null !== (_this$plugins$getValu2 = this.plugins.getValue(PageSize)) && void 0 !== _this$plugins$getValu2 ? _this$plugins$getValu2 : "all";
            if ("auto" === this.props.allowedPageSizes) {
                if ("all" === pageSize) {
                    return []
                }
                return [Math.floor(pageSize / 2), pageSize, 2 * pageSize]
            }
            return this.props.allowedPageSizes
        })()
    }
    get restAttributes() {
        var _this$props = this.props,
            restProps = _objectWithoutPropertiesLoose(_this$props, _excluded);
        return restProps
    }
    componentWillUpdate(nextProps, nextState, context) {
        if (this.context.PluginsContext !== context.PluginsContext || this.props.allowedPageSizes !== nextProps.allowedPageSizes) {
            this.__getterCache.allowedPageSizes = void 0
        }
    }
    render() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            plugins: this.plugins,
            onPageSizeChange: this.onPageSizeChange,
            onPageIndexChange: this.onPageIndexChange,
            allowedPageSizes: this.allowedPageSizes,
            restAttributes: this.restAttributes
        })
    }
}
Pager.defaultProps = PagerProps;
