/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/paging/paging.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["defaultPageIndex", "defaultPageSize", "enabled", "pageIndex", "pageIndexChange", "pageSize", "pageSizeChange"];
import {
    createFragment,
    createComponentVNode
} from "inferno";
import {
    Fragment
} from "inferno";
import {
    BaseInfernoComponent
} from "@devextreme/runtime/inferno";
import {
    ValueSetter
} from "../../../../utils/plugin/value_setter";
import {
    GetterExtender
} from "../../../../utils/plugin/getter_extender";
import {
    VisibleItems
} from "../data_grid_light";
import {
    PageIndex,
    PageSize,
    SetPageIndex,
    SetPageSize
} from "./plugins";
export var viewFunction = viewModel => createFragment([createComponentVNode(2, ValueSetter, {
    type: PageIndex,
    value: viewModel.props.pageIndex
}), createComponentVNode(2, ValueSetter, {
    type: PageSize,
    value: viewModel.pageSize
}), createComponentVNode(2, ValueSetter, {
    type: SetPageIndex,
    value: viewModel.setPageIndex
}), createComponentVNode(2, ValueSetter, {
    type: SetPageSize,
    value: viewModel.setPageSize
}), createComponentVNode(2, GetterExtender, {
    type: VisibleItems,
    order: 1,
    func: viewModel.calculateVisibleItems
})], 4);
export var PagingProps = {
    enabled: true,
    defaultPageSize: 20,
    pageSizeChange: () => {},
    defaultPageIndex: 0,
    pageIndexChange: () => {}
};
export class Paging extends BaseInfernoComponent {
    constructor(props) {
        super(props);
        this.state = {
            pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.props.defaultPageSize,
            pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.props.defaultPageIndex
        };
        this.setPageIndex = this.setPageIndex.bind(this);
        this.setPageSize = this.setPageSize.bind(this);
        this.calculateVisibleItems = this.calculateVisibleItems.bind(this)
    }
    get pageSize() {
        if (0 === (void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize)) {
            return "all"
        }
        return void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize
    }
    setPageIndex(pageIndex) {
        var __newValue;
        this.setState(__state_argument => {
            __newValue = pageIndex;
            return {
                pageIndex: __newValue
            }
        });
        this.props.pageIndexChange(__newValue)
    }
    setPageSize(pageSize) {
        var __newValue;
        this.setState(__state_argument => {
            __newValue = pageSize;
            return {
                pageSize: __newValue
            }
        });
        this.props.pageSizeChange(__newValue)
    }
    calculateVisibleItems(dataSource) {
        if (!this.props.enabled || "all" === this.pageSize) {
            return dataSource
        }
        var pageSize = this.pageSize;
        var start = (void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex) * pageSize;
        var end = start + pageSize;
        return dataSource.slice(start, end)
    }
    get restAttributes() {
        var _this$props$pageSize$ = _extends({}, this.props, {
                pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize,
                pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex
            }),
            restProps = _objectWithoutPropertiesLoose(_this$props$pageSize$, _excluded);
        return restProps
    }
    render() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props, {
                pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize,
                pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex
            }),
            pageSize: this.pageSize,
            setPageIndex: this.setPageIndex,
            setPageSize: this.setPageSize,
            calculateVisibleItems: this.calculateVisibleItems,
            restAttributes: this.restAttributes
        })
    }
}
Paging.defaultProps = PagingProps;
