/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/selection/selection.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["allowSelectAll", "defaultSelectedRowKeys", "mode", "selectAllMode", "selectedRowKeys", "selectedRowKeysChange"];
import {
    createFragment
} from "inferno";
import {
    InfernoEffect,
    InfernoComponent
} from "@devextreme/runtime/inferno";
import {
    PluginsContext
} from "../../../../utils/plugin/context";
import {
    SelectionCheckbox
} from "./select_checkbox";
import {
    SelectAllCheckbox
} from "./select_all_checkbox";
import {
    KeyExprPlugin,
    VisibleColumns,
    VisibleItems,
    DataSource
} from "../data_grid_light";
import {
    DataRowClassesGetter,
    DataRowPropertiesGetter
} from "../widgets/data_row";
import {
    RowClick
} from "../views/table_content";
import {
    ClearSelection,
    IsSelected,
    SelectableCount,
    SelectAll,
    SelectedCount,
    SetSelected
} from "./plugins";
export var viewFunction = () => createFragment();
export var SelectionProps = {
    mode: "single",
    allowSelectAll: true,
    selectAllMode: "allPages",
    defaultSelectedRowKeys: Object.freeze([]),
    selectedRowKeysChange: () => {}
};
export class Selection extends InfernoComponent {
    constructor(props) {
        super(props);
        this.state = {
            keyExpr: "",
            selectedRowKeys: void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.props.defaultSelectedRowKeys
        };
        this.watchKeyExpr = this.watchKeyExpr.bind(this);
        this.addVisibleColumnsHandler = this.addVisibleColumnsHandler.bind(this);
        this.addPluginMethods = this.addPluginMethods.bind(this);
        this.addPluginValues = this.addPluginValues.bind(this);
        this.extendDataRowAttributes = this.extendDataRowAttributes.bind(this);
        this.extendDataRowClasses = this.extendDataRowClasses.bind(this);
        this.setRowClickEvent = this.setRowClickEvent.bind(this);
        this.selectAll = this.selectAll.bind(this);
        this.clearSelection = this.clearSelection.bind(this);
        this.isSelected = this.isSelected.bind(this);
        this.setSelected = this.setSelected.bind(this);
        this.selectableCount = this.selectableCount.bind(this);
        this.invertSelected = this.invertSelected.bind(this);
        this.getAllItems = this.getAllItems.bind(this)
    }
    get plugins() {
        if ("PluginsContext" in this.context) {
            return this.context.PluginsContext
        }
        return PluginsContext
    }
    createEffects() {
        return [new InfernoEffect(this.watchKeyExpr, [this.plugins]), new InfernoEffect(this.addVisibleColumnsHandler, [this.props.mode, this.plugins, this.props.allowSelectAll]), new InfernoEffect(this.addPluginMethods, [this.plugins, this.props.mode, this.props.selectedRowKeysChange, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.selectAllMode]), new InfernoEffect(this.addPluginValues, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.props.selectAllMode]), new InfernoEffect(this.extendDataRowAttributes, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]), new InfernoEffect(this.extendDataRowClasses, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]), new InfernoEffect(this.setRowClickEvent, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.mode, this.props.selectedRowKeysChange])]
    }
    updateEffects() {
        var _this$_effects$, _this$_effects$2, _this$_effects$3, _this$_effects$4, _this$_effects$5, _this$_effects$6, _this$_effects$7;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins]);
        null === (_this$_effects$2 = this._effects[1]) || void 0 === _this$_effects$2 ? void 0 : _this$_effects$2.update([this.props.mode, this.plugins, this.props.allowSelectAll]);
        null === (_this$_effects$3 = this._effects[2]) || void 0 === _this$_effects$3 ? void 0 : _this$_effects$3.update([this.plugins, this.props.mode, this.props.selectedRowKeysChange, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.selectAllMode]);
        null === (_this$_effects$4 = this._effects[3]) || void 0 === _this$_effects$4 ? void 0 : _this$_effects$4.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.props.selectAllMode]);
        null === (_this$_effects$5 = this._effects[4]) || void 0 === _this$_effects$5 ? void 0 : _this$_effects$5.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]);
        null === (_this$_effects$6 = this._effects[5]) || void 0 === _this$_effects$6 ? void 0 : _this$_effects$6.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]);
        null === (_this$_effects$7 = this._effects[6]) || void 0 === _this$_effects$7 ? void 0 : _this$_effects$7.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.mode, this.props.selectedRowKeysChange])
    }
    watchKeyExpr() {
        return this.plugins.watch(KeyExprPlugin, keyExpr => {
            this.setState(__state_argument => ({
                keyExpr: keyExpr
            }))
        })
    }
    addVisibleColumnsHandler() {
        if ("none" !== this.props.mode) {
            return this.plugins.extend(VisibleColumns, 1, columns => {
                var selectColumn = {
                    cellTemplate: SelectionCheckbox
                };
                if ("multiple" === this.props.mode && this.props.allowSelectAll) {
                    selectColumn.headerTemplate = SelectAllCheckbox
                }
                return [selectColumn, ...columns]
            })
        }
        return
    }
    addPluginMethods() {
        this.plugins.set(SetSelected, this.setSelected);
        this.plugins.set(IsSelected, this.isSelected);
        this.plugins.set(ClearSelection, this.clearSelection);
        this.plugins.set(SelectAll, this.selectAll)
    }
    addPluginValues() {
        this.plugins.set(SelectedCount, (void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys).length);
        this.plugins.set(SelectableCount, this.selectableCount())
    }
    extendDataRowAttributes() {
        return this.plugins.extend(DataRowPropertiesGetter, 1, base => data => {
            if (this.isSelected(data)) {
                return _extends({}, base(data), {
                    "aria-selected": true
                })
            }
            return base(data)
        })
    }
    extendDataRowClasses() {
        return this.plugins.extend(DataRowClassesGetter, 1, base => data => {
            if (this.isSelected(data)) {
                return _extends({}, base(data), {
                    "dx-selection": true
                })
            }
            return base(data)
        })
    }
    setRowClickEvent() {
        this.plugins.set(RowClick, data => {
            this.invertSelected(data)
        })
    }
    isSelected(data) {
        return (void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys).includes(data[this.state.keyExpr])
    }
    setSelected(data, value) {
        if (value) {
            if ("multiple" === this.props.mode) {
                var __newValue;
                this.setState(__state_argument => {
                    __newValue = [...void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : __state_argument.selectedRowKeys, data[this.state.keyExpr]];
                    return {
                        selectedRowKeys: __newValue
                    }
                });
                this.props.selectedRowKeysChange(__newValue)
            } else {
                var _newValue;
                this.setState(__state_argument => {
                    _newValue = [data[this.state.keyExpr]];
                    return {
                        selectedRowKeys: _newValue
                    }
                });
                this.props.selectedRowKeysChange(_newValue)
            }
        } else {
            var _newValue2;
            this.setState(__state_argument => {
                _newValue2 = (void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : __state_argument.selectedRowKeys).filter(i => i !== data[this.state.keyExpr]);
                return {
                    selectedRowKeys: _newValue2
                }
            });
            this.props.selectedRowKeysChange(_newValue2)
        }
    }
    selectableCount() {
        var items = this.getAllItems();
        return items.length
    }
    invertSelected(data) {
        var isSelected = this.isSelected(data);
        this.setSelected(data, !isSelected)
    }
    getAllItems() {
        var _ref;
        return null !== (_ref = "allPages" === this.props.selectAllMode ? this.plugins.getValue(DataSource) : this.plugins.getValue(VisibleItems)) && void 0 !== _ref ? _ref : []
    }
    get restAttributes() {
        var _this$props$selectedR = _extends({}, this.props, {
                selectedRowKeys: void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys
            }),
            restProps = _objectWithoutPropertiesLoose(_this$props$selectedR, _excluded);
        return restProps
    }
    selectAll() {
        var items = this.getAllItems();
        var __newValue;
        this.setState(__state_argument => {
            __newValue = items.map(item => item[this.state.keyExpr]);
            return {
                selectedRowKeys: __newValue
            }
        });
        this.props.selectedRowKeysChange(__newValue)
    }
    clearSelection() {
        var __newValue;
        this.setState(__state_argument => {
            __newValue = [];
            return {
                selectedRowKeys: __newValue
            }
        });
        this.props.selectedRowKeysChange(__newValue)
    }
    render() {
        this.props;
        return viewFunction()
    }
}
Selection.defaultProps = SelectionProps;
