/**
 * DevExtreme (renovation/ui/grids/data_grid_light/pager/pager.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.PagerProps = exports.Pager = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _placeholder_extender = require("../../../../utils/plugin/placeholder_extender");
var _message = _interopRequireDefault(require("../../../../../localization/message"));
var _content = require("../../../pager/content");
var _plugins = require("../paging/plugins");
var _data_grid_light = require("../data_grid_light");
var _footer = require("../views/footer");
var _context = require("../../../../utils/plugin/context");
var _excluded = ["allowedPageSizes", "displayMode", "infoText", "showInfo", "showNavigationButtons", "showPageSizeSelector", "visible"];

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _assertThisInitialized(self) {
    if (void 0 === self) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called")
    }
    return self
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}

function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest()
}

function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")
}

function _unsupportedIterableToArray(o, minLen) {
    if (!o) {
        return
    }
    if ("string" === typeof o) {
        return _arrayLikeToArray(o, minLen)
    }
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if ("Object" === n && o.constructor) {
        n = o.constructor.name
    }
    if ("Map" === n || "Set" === n) {
        return Array.from(o)
    }
    if ("Arguments" === n || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) {
        return _arrayLikeToArray(o, minLen)
    }
}

function _arrayLikeToArray(arr, len) {
    if (null == len || len > arr.length) {
        len = arr.length
    }
    for (var i = 0, arr2 = new Array(len); i < len; i++) {
        arr2[i] = arr[i]
    }
    return arr2
}

function _iterableToArrayLimit(arr, i) {
    var _i = null == arr ? null : "undefined" !== typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"];
    if (null == _i) {
        return
    }
    var _arr = [];
    var _n = true;
    var _d = false;
    var _s, _e;
    try {
        for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
            _arr.push(_s.value);
            if (i && _arr.length === i) {
                break
            }
        }
    } catch (err) {
        _d = true;
        _e = err
    } finally {
        try {
            if (!_n && null != _i.return) {
                _i.return()
            }
        } finally {
            if (_d) {
                throw _e
            }
        }
    }
    return _arr
}

function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) {
        return arr
    }
}
var DATAGRID_PAGER_CLASS = "dx-datagrid-pager";
var viewFunction = function(viewModel) {
    return (0, _inferno.createComponentVNode)(2, _placeholder_extender.PlaceholderExtender, {
        type: _footer.FooterPlaceholder,
        order: 1,
        deps: [_plugins.PageIndex, _plugins.PageSize, _data_grid_light.TotalCount, _plugins.PageCount],
        template: function(_ref) {
            var _ref2 = _slicedToArray(_ref, 4),
                pageIndex = _ref2[0],
                pageSize = _ref2[1],
                totalCount = _ref2[2],
                pageCount = _ref2[3];
            return (0, _inferno.createComponentVNode)(2, _content.PagerContent, {
                className: DATAGRID_PAGER_CLASS,
                pageSizes: viewModel.allowedPageSizes,
                displayMode: viewModel.props.displayMode,
                infoText: viewModel.props.infoText,
                showInfo: viewModel.props.showInfo,
                showNavigationButtons: viewModel.props.showNavigationButtons,
                showPageSizes: viewModel.props.showPageSizeSelector,
                pageCount: pageCount,
                visible: viewModel.props.visible,
                totalCount: totalCount,
                pageIndex: pageIndex,
                pageIndexChange: viewModel.onPageIndexChange,
                pageSize: "all" === pageSize ? 0 : pageSize,
                pageSizeChange: viewModel.onPageSizeChange
            })
        }
    })
};
exports.viewFunction = viewFunction;
var PagerProps = Object.defineProperties({
    allowedPageSizes: "auto",
    displayMode: "adaptive",
    showInfo: false,
    showNavigationButtons: false,
    showPageSizeSelector: false,
    visible: true
}, {
    infoText: {
        get: function() {
            return _message.default.format("dxPager-infoText")
        },
        configurable: true,
        enumerable: true
    }
});
exports.PagerProps = PagerProps;
var Pager = function(_BaseInfernoComponent) {
    _inheritsLoose(Pager, _BaseInfernoComponent);

    function Pager(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {};
        _this.__getterCache = {};
        _this.onPageSizeChange = _this.onPageSizeChange.bind(_assertThisInitialized(_this));
        _this.onPageIndexChange = _this.onPageIndexChange.bind(_assertThisInitialized(_this));
        return _this
    }
    var _proto = Pager.prototype;
    _proto.onPageSizeChange = function(pageSize) {
        var setPageSize = this.plugins.getValue(_plugins.SetPageSize);
        if (!setPageSize) {
            return
        }
        if (0 === pageSize) {
            setPageSize("all")
        } else {
            setPageSize(pageSize)
        }
    };
    _proto.onPageIndexChange = function(pageIndex) {
        var _this$plugins$getValu;
        null === (_this$plugins$getValu = this.plugins.getValue(_plugins.SetPageIndex)) || void 0 === _this$plugins$getValu ? void 0 : _this$plugins$getValu(pageIndex)
    };
    _proto.componentWillUpdate = function(nextProps, nextState, context) {
        if (this.context.PluginsContext !== context.PluginsContext || this.props.allowedPageSizes !== nextProps.allowedPageSizes) {
            this.__getterCache.allowedPageSizes = void 0
        }
    };
    _proto.render = function() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            plugins: this.plugins,
            onPageSizeChange: this.onPageSizeChange,
            onPageIndexChange: this.onPageIndexChange,
            allowedPageSizes: this.allowedPageSizes,
            restAttributes: this.restAttributes
        })
    };
    _createClass(Pager, [{
        key: "plugins",
        get: function() {
            if ("PluginsContext" in this.context) {
                return this.context.PluginsContext
            }
            return _context.PluginsContext
        }
    }, {
        key: "allowedPageSizes",
        get: function() {
            var _this2 = this;
            if (void 0 !== this.__getterCache.allowedPageSizes) {
                return this.__getterCache.allowedPageSizes
            }
            return this.__getterCache.allowedPageSizes = function() {
                var _this2$plugins$getVal;
                var pageSize = null !== (_this2$plugins$getVal = _this2.plugins.getValue(_plugins.PageSize)) && void 0 !== _this2$plugins$getVal ? _this2$plugins$getVal : "all";
                if ("auto" === _this2.props.allowedPageSizes) {
                    if ("all" === pageSize) {
                        return []
                    }
                    return [Math.floor(pageSize / 2), pageSize, 2 * pageSize]
                }
                return _this2.props.allowedPageSizes
            }()
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props = this.props,
                restProps = (_this$props.allowedPageSizes, _this$props.displayMode, _this$props.infoText, _this$props.showInfo, _this$props.showNavigationButtons, _this$props.showPageSizeSelector, _this$props.visible, _objectWithoutProperties(_this$props, _excluded));
            return restProps
        }
    }]);
    return Pager
}(_inferno2.BaseInfernoComponent);
exports.Pager = Pager;
Pager.defaultProps = PagerProps;
