/**
 * DevExtreme (renovation/ui/grids/data_grid_light/paging/paging.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.PagingProps = exports.Paging = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _value_setter = require("../../../../utils/plugin/value_setter");
var _getter_extender = require("../../../../utils/plugin/getter_extender");
var _data_grid_light = require("../data_grid_light");
var _plugins = require("./plugins");
var _excluded = ["defaultPageIndex", "defaultPageSize", "enabled", "pageIndex", "pageIndexChange", "pageSize", "pageSizeChange"];

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _assertThisInitialized(self) {
    if (void 0 === self) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called")
    }
    return self
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var viewFunction = function(viewModel) {
    return (0, _inferno.createFragment)([(0, _inferno.createComponentVNode)(2, _value_setter.ValueSetter, {
        type: _plugins.PageIndex,
        value: viewModel.props.pageIndex
    }), (0, _inferno.createComponentVNode)(2, _value_setter.ValueSetter, {
        type: _plugins.PageSize,
        value: viewModel.pageSize
    }), (0, _inferno.createComponentVNode)(2, _value_setter.ValueSetter, {
        type: _plugins.SetPageIndex,
        value: viewModel.setPageIndex
    }), (0, _inferno.createComponentVNode)(2, _value_setter.ValueSetter, {
        type: _plugins.SetPageSize,
        value: viewModel.setPageSize
    }), (0, _inferno.createComponentVNode)(2, _getter_extender.GetterExtender, {
        type: _data_grid_light.VisibleItems,
        order: 1,
        func: viewModel.calculateVisibleItems
    })], 4)
};
exports.viewFunction = viewFunction;
var PagingProps = {
    enabled: true,
    defaultPageSize: 20,
    pageSizeChange: function() {},
    defaultPageIndex: 0,
    pageIndexChange: function() {}
};
exports.PagingProps = PagingProps;
var Paging = function(_BaseInfernoComponent) {
    _inheritsLoose(Paging, _BaseInfernoComponent);

    function Paging(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {
            pageSize: void 0 !== _this.props.pageSize ? _this.props.pageSize : _this.props.defaultPageSize,
            pageIndex: void 0 !== _this.props.pageIndex ? _this.props.pageIndex : _this.props.defaultPageIndex
        };
        _this.setPageIndex = _this.setPageIndex.bind(_assertThisInitialized(_this));
        _this.setPageSize = _this.setPageSize.bind(_assertThisInitialized(_this));
        _this.calculateVisibleItems = _this.calculateVisibleItems.bind(_assertThisInitialized(_this));
        return _this
    }
    var _proto = Paging.prototype;
    _proto.setPageIndex = function(pageIndex) {
        var __newValue;
        this.setState((function(__state_argument) {
            __newValue = pageIndex;
            return {
                pageIndex: __newValue
            }
        }));
        this.props.pageIndexChange(__newValue)
    };
    _proto.setPageSize = function(pageSize) {
        var __newValue;
        this.setState((function(__state_argument) {
            __newValue = pageSize;
            return {
                pageSize: __newValue
            }
        }));
        this.props.pageSizeChange(__newValue)
    };
    _proto.calculateVisibleItems = function(dataSource) {
        if (!this.props.enabled || "all" === this.pageSize) {
            return dataSource
        }
        var pageSize = this.pageSize;
        var start = (void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex) * pageSize;
        var end = start + pageSize;
        return dataSource.slice(start, end)
    };
    _proto.render = function() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props, {
                pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize,
                pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex
            }),
            pageSize: this.pageSize,
            setPageIndex: this.setPageIndex,
            setPageSize: this.setPageSize,
            calculateVisibleItems: this.calculateVisibleItems,
            restAttributes: this.restAttributes
        })
    };
    _createClass(Paging, [{
        key: "pageSize",
        get: function() {
            if (0 === (void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize)) {
                return "all"
            }
            return void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props$pageSize$ = _extends({}, this.props, {
                    pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize,
                    pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex
                }),
                restProps = (_this$props$pageSize$.defaultPageIndex, _this$props$pageSize$.defaultPageSize, _this$props$pageSize$.enabled, _this$props$pageSize$.pageIndex, _this$props$pageSize$.pageIndexChange, _this$props$pageSize$.pageSize, _this$props$pageSize$.pageSizeChange, _objectWithoutProperties(_this$props$pageSize$, _excluded));
            return restProps
        }
    }]);
    return Paging
}(_inferno2.BaseInfernoComponent);
exports.Paging = Paging;
Paging.defaultProps = PagingProps;
