/**
 * DevExtreme (renovation/ui/grids/data_grid_light/selection/selection.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.SelectionProps = exports.Selection = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _context = require("../../../../utils/plugin/context");
var _select_checkbox = require("./select_checkbox");
var _select_all_checkbox = require("./select_all_checkbox");
var _data_grid_light = require("../data_grid_light");
var _data_row = require("../widgets/data_row");
var _table_content = require("../views/table_content");
var _plugins = require("./plugins");
var _excluded = ["allowSelectAll", "defaultSelectedRowKeys", "mode", "selectAllMode", "selectedRowKeys", "selectedRowKeysChange"];

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread()
}

function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")
}

function _unsupportedIterableToArray(o, minLen) {
    if (!o) {
        return
    }
    if ("string" === typeof o) {
        return _arrayLikeToArray(o, minLen)
    }
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if ("Object" === n && o.constructor) {
        n = o.constructor.name
    }
    if ("Map" === n || "Set" === n) {
        return Array.from(o)
    }
    if ("Arguments" === n || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) {
        return _arrayLikeToArray(o, minLen)
    }
}

function _iterableToArray(iter) {
    if ("undefined" !== typeof Symbol && null != iter[Symbol.iterator] || null != iter["@@iterator"]) {
        return Array.from(iter)
    }
}

function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        return _arrayLikeToArray(arr)
    }
}

function _arrayLikeToArray(arr, len) {
    if (null == len || len > arr.length) {
        len = arr.length
    }
    for (var i = 0, arr2 = new Array(len); i < len; i++) {
        arr2[i] = arr[i]
    }
    return arr2
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _assertThisInitialized(self) {
    if (void 0 === self) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called")
    }
    return self
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var viewFunction = function() {
    return (0, _inferno.createFragment)()
};
exports.viewFunction = viewFunction;
var SelectionProps = {
    mode: "single",
    allowSelectAll: true,
    selectAllMode: "allPages",
    defaultSelectedRowKeys: Object.freeze([]),
    selectedRowKeysChange: function() {}
};
exports.SelectionProps = SelectionProps;
var Selection = function(_InfernoComponent) {
    _inheritsLoose(Selection, _InfernoComponent);

    function Selection(props) {
        var _this;
        _this = _InfernoComponent.call(this, props) || this;
        _this.state = {
            keyExpr: "",
            selectedRowKeys: void 0 !== _this.props.selectedRowKeys ? _this.props.selectedRowKeys : _this.props.defaultSelectedRowKeys
        };
        _this.watchKeyExpr = _this.watchKeyExpr.bind(_assertThisInitialized(_this));
        _this.addVisibleColumnsHandler = _this.addVisibleColumnsHandler.bind(_assertThisInitialized(_this));
        _this.addPluginMethods = _this.addPluginMethods.bind(_assertThisInitialized(_this));
        _this.addPluginValues = _this.addPluginValues.bind(_assertThisInitialized(_this));
        _this.extendDataRowAttributes = _this.extendDataRowAttributes.bind(_assertThisInitialized(_this));
        _this.extendDataRowClasses = _this.extendDataRowClasses.bind(_assertThisInitialized(_this));
        _this.setRowClickEvent = _this.setRowClickEvent.bind(_assertThisInitialized(_this));
        _this.selectAll = _this.selectAll.bind(_assertThisInitialized(_this));
        _this.clearSelection = _this.clearSelection.bind(_assertThisInitialized(_this));
        _this.isSelected = _this.isSelected.bind(_assertThisInitialized(_this));
        _this.setSelected = _this.setSelected.bind(_assertThisInitialized(_this));
        _this.selectableCount = _this.selectableCount.bind(_assertThisInitialized(_this));
        _this.invertSelected = _this.invertSelected.bind(_assertThisInitialized(_this));
        _this.getAllItems = _this.getAllItems.bind(_assertThisInitialized(_this));
        return _this
    }
    var _proto = Selection.prototype;
    _proto.createEffects = function() {
        return [new _inferno2.InfernoEffect(this.watchKeyExpr, [this.plugins]), new _inferno2.InfernoEffect(this.addVisibleColumnsHandler, [this.props.mode, this.plugins, this.props.allowSelectAll]), new _inferno2.InfernoEffect(this.addPluginMethods, [this.plugins, this.props.mode, this.props.selectedRowKeysChange, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.selectAllMode]), new _inferno2.InfernoEffect(this.addPluginValues, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.props.selectAllMode]), new _inferno2.InfernoEffect(this.extendDataRowAttributes, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]), new _inferno2.InfernoEffect(this.extendDataRowClasses, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]), new _inferno2.InfernoEffect(this.setRowClickEvent, [this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.mode, this.props.selectedRowKeysChange])]
    };
    _proto.updateEffects = function() {
        var _this$_effects$, _this$_effects$2, _this$_effects$3, _this$_effects$4, _this$_effects$5, _this$_effects$6, _this$_effects$7;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins]);
        null === (_this$_effects$2 = this._effects[1]) || void 0 === _this$_effects$2 ? void 0 : _this$_effects$2.update([this.props.mode, this.plugins, this.props.allowSelectAll]);
        null === (_this$_effects$3 = this._effects[2]) || void 0 === _this$_effects$3 ? void 0 : _this$_effects$3.update([this.plugins, this.props.mode, this.props.selectedRowKeysChange, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.selectAllMode]);
        null === (_this$_effects$4 = this._effects[3]) || void 0 === _this$_effects$4 ? void 0 : _this$_effects$4.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.props.selectAllMode]);
        null === (_this$_effects$5 = this._effects[4]) || void 0 === _this$_effects$5 ? void 0 : _this$_effects$5.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]);
        null === (_this$_effects$6 = this._effects[5]) || void 0 === _this$_effects$6 ? void 0 : _this$_effects$6.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr]);
        null === (_this$_effects$7 = this._effects[6]) || void 0 === _this$_effects$7 ? void 0 : _this$_effects$7.update([this.plugins, this.state.selectedRowKeys, this.props.selectedRowKeys, this.state.keyExpr, this.props.mode, this.props.selectedRowKeysChange])
    };
    _proto.watchKeyExpr = function() {
        var _this2 = this;
        return this.plugins.watch(_data_grid_light.KeyExprPlugin, (function(keyExpr) {
            _this2.setState((function(__state_argument) {
                return {
                    keyExpr: keyExpr
                }
            }))
        }))
    };
    _proto.addVisibleColumnsHandler = function() {
        var _this3 = this;
        if ("none" !== this.props.mode) {
            return this.plugins.extend(_data_grid_light.VisibleColumns, 1, (function(columns) {
                var selectColumn = {
                    cellTemplate: _select_checkbox.SelectionCheckbox
                };
                if ("multiple" === _this3.props.mode && _this3.props.allowSelectAll) {
                    selectColumn.headerTemplate = _select_all_checkbox.SelectAllCheckbox
                }
                return [selectColumn].concat(_toConsumableArray(columns))
            }))
        }
        return
    };
    _proto.addPluginMethods = function() {
        this.plugins.set(_plugins.SetSelected, this.setSelected);
        this.plugins.set(_plugins.IsSelected, this.isSelected);
        this.plugins.set(_plugins.ClearSelection, this.clearSelection);
        this.plugins.set(_plugins.SelectAll, this.selectAll)
    };
    _proto.addPluginValues = function() {
        this.plugins.set(_plugins.SelectedCount, (void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys).length);
        this.plugins.set(_plugins.SelectableCount, this.selectableCount())
    };
    _proto.extendDataRowAttributes = function() {
        var _this4 = this;
        return this.plugins.extend(_data_row.DataRowPropertiesGetter, 1, (function(base) {
            return function(data) {
                if (_this4.isSelected(data)) {
                    return _extends({}, base(data), {
                        "aria-selected": true
                    })
                }
                return base(data)
            }
        }))
    };
    _proto.extendDataRowClasses = function() {
        var _this5 = this;
        return this.plugins.extend(_data_row.DataRowClassesGetter, 1, (function(base) {
            return function(data) {
                if (_this5.isSelected(data)) {
                    return _extends({}, base(data), {
                        "dx-selection": true
                    })
                }
                return base(data)
            }
        }))
    };
    _proto.setRowClickEvent = function() {
        var _this6 = this;
        this.plugins.set(_table_content.RowClick, (function(data) {
            _this6.invertSelected(data)
        }))
    };
    _proto.isSelected = function(data) {
        return (void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys).includes(data[this.state.keyExpr])
    };
    _proto.setSelected = function(data, value) {
        var _this7 = this;
        if (value) {
            if ("multiple" === this.props.mode) {
                var __newValue;
                this.setState((function(__state_argument) {
                    __newValue = [].concat(_toConsumableArray(void 0 !== _this7.props.selectedRowKeys ? _this7.props.selectedRowKeys : __state_argument.selectedRowKeys), [data[_this7.state.keyExpr]]);
                    return {
                        selectedRowKeys: __newValue
                    }
                }));
                this.props.selectedRowKeysChange(__newValue)
            } else {
                var _newValue;
                this.setState((function(__state_argument) {
                    _newValue = [data[_this7.state.keyExpr]];
                    return {
                        selectedRowKeys: _newValue
                    }
                }));
                this.props.selectedRowKeysChange(_newValue)
            }
        } else {
            var _newValue2;
            this.setState((function(__state_argument) {
                _newValue2 = (void 0 !== _this7.props.selectedRowKeys ? _this7.props.selectedRowKeys : __state_argument.selectedRowKeys).filter((function(i) {
                    return i !== data[_this7.state.keyExpr]
                }));
                return {
                    selectedRowKeys: _newValue2
                }
            }));
            this.props.selectedRowKeysChange(_newValue2)
        }
    };
    _proto.selectableCount = function() {
        var items = this.getAllItems();
        return items.length
    };
    _proto.invertSelected = function(data) {
        var isSelected = this.isSelected(data);
        this.setSelected(data, !isSelected)
    };
    _proto.getAllItems = function() {
        var _ref;
        return null !== (_ref = "allPages" === this.props.selectAllMode ? this.plugins.getValue(_data_grid_light.DataSource) : this.plugins.getValue(_data_grid_light.VisibleItems)) && void 0 !== _ref ? _ref : []
    };
    _proto.selectAll = function() {
        var _this8 = this;
        var items = this.getAllItems();
        var __newValue;
        this.setState((function(__state_argument) {
            __newValue = items.map((function(item) {
                return item[_this8.state.keyExpr]
            }));
            return {
                selectedRowKeys: __newValue
            }
        }));
        this.props.selectedRowKeysChange(__newValue)
    };
    _proto.clearSelection = function() {
        var __newValue;
        this.setState((function(__state_argument) {
            __newValue = [];
            return {
                selectedRowKeys: __newValue
            }
        }));
        this.props.selectedRowKeysChange(__newValue)
    };
    _proto.render = function() {
        this.props;
        return viewFunction()
    };
    _createClass(Selection, [{
        key: "plugins",
        get: function() {
            if ("PluginsContext" in this.context) {
                return this.context.PluginsContext
            }
            return _context.PluginsContext
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props$selectedR = _extends({}, this.props, {
                    selectedRowKeys: void 0 !== this.props.selectedRowKeys ? this.props.selectedRowKeys : this.state.selectedRowKeys
                }),
                restProps = (_this$props$selectedR.allowSelectAll, _this$props$selectedR.defaultSelectedRowKeys, _this$props$selectedR.mode, _this$props$selectedR.selectAllMode, _this$props$selectedR.selectedRowKeys, _this$props$selectedR.selectedRowKeysChange, _objectWithoutProperties(_this$props$selectedR, _excluded));
            return restProps
        }
    }]);
    return Selection
}(_inferno2.InfernoComponent);
exports.Selection = Selection;
Selection.defaultProps = SelectionProps;
